pub struct DebuggerMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on debugger resources.
It is not used directly, but through the CloudDebugger hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_clouddebugger2 as clouddebugger2;
use clouddebugger2::{CloudDebugger, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CloudDebugger::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `debuggees_breakpoints_delete(...)`, `debuggees_breakpoints_get(...)`, `debuggees_breakpoints_list(...)`, `debuggees_breakpoints_set(...)` and `debuggees_list(...)`
// to build up your call.
let rb = hub.debugger();Implementations
Sourceimpl<'a, C> DebuggerMethods<'a, C>
impl<'a, C> DebuggerMethods<'a, C>
Sourcepub fn debuggees_breakpoints_delete(
&self,
debuggee_id: &str,
breakpoint_id: &str,
) -> DebuggerDebuggeeBreakpointDeleteCall<'a, C>
pub fn debuggees_breakpoints_delete( &self, debuggee_id: &str, breakpoint_id: &str, ) -> DebuggerDebuggeeBreakpointDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes the breakpoint from the debuggee.
Arguments
debuggeeId- Required. ID of the debuggee whose breakpoint to delete.breakpointId- Required. ID of the breakpoint to delete.
Sourcepub fn debuggees_breakpoints_get(
&self,
debuggee_id: &str,
breakpoint_id: &str,
) -> DebuggerDebuggeeBreakpointGetCall<'a, C>
pub fn debuggees_breakpoints_get( &self, debuggee_id: &str, breakpoint_id: &str, ) -> DebuggerDebuggeeBreakpointGetCall<'a, C>
Create a builder to help you perform the following task:
Gets breakpoint information.
Arguments
debuggeeId- Required. ID of the debuggee whose breakpoint to get.breakpointId- Required. ID of the breakpoint to get.
Sourcepub fn debuggees_breakpoints_list(
&self,
debuggee_id: &str,
) -> DebuggerDebuggeeBreakpointListCall<'a, C>
pub fn debuggees_breakpoints_list( &self, debuggee_id: &str, ) -> DebuggerDebuggeeBreakpointListCall<'a, C>
Create a builder to help you perform the following task:
Lists all breakpoints for the debuggee.
Arguments
debuggeeId- Required. ID of the debuggee whose breakpoints to list.
Sourcepub fn debuggees_breakpoints_set(
&self,
request: Breakpoint,
debuggee_id: &str,
) -> DebuggerDebuggeeBreakpointSetCall<'a, C>
pub fn debuggees_breakpoints_set( &self, request: Breakpoint, debuggee_id: &str, ) -> DebuggerDebuggeeBreakpointSetCall<'a, C>
Create a builder to help you perform the following task:
Sets the breakpoint to the debuggee.
Arguments
request- No description provided.debuggeeId- Required. ID of the debuggee where the breakpoint is to be set.
Sourcepub fn debuggees_list(&self) -> DebuggerDebuggeeListCall<'a, C>
pub fn debuggees_list(&self) -> DebuggerDebuggeeListCall<'a, C>
Create a builder to help you perform the following task:
Lists all the debuggees that the user has access to.